summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/timeplt.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/timeplt.cpp')
-rw-r--r--src/mame/audio/timeplt.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/timeplt.cpp b/src/mame/audio/timeplt.cpp
index f0302ec0be2..7fe94dd46c7 100644
--- a/src/mame/audio/timeplt.cpp
+++ b/src/mame/audio/timeplt.cpp
@@ -228,11 +228,11 @@ void locomotn_audio_device::device_add_mconfig(machine_config &config)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void timeplt_audio_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void timeplt_audio_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
// should never get here
- fatalerror("sound_stream_update called; not applicable to legacy sound devices\n");
+ fatalerror("sound_stream_update_legacy called; not applicable to legacy sound devices\n");
}
@@ -228,11 +228,11 @@ void locomotn_audio_device::device_add_mconfig(machine_config &config)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------